@@ -1,17 +1,32 @@
-from typing import List, Optional, Callable
+from __future__ import annotations
+from typing import Optional, Callable
 
 import tensorflow as tf
 
-from .model_score import ModelScoreCallback
 from .save import ModelSave
-from .weight_decay import WeightDecayScheduler
+from .weight_decay_scheduler import WeightDecayScheduler
+from .learning_rate_scheduler import LearningRateScheduler
+
+from .tagging_fscore_metric import TaggingFScoreMetric
 
 
 def create_exponential_decay_scheduler(
-    update_factor: float, update_epochs: int
+    update_factor: float,
+    update_epochs: int,
 ) -> Callable[[int, float], float]:
-    def scheduler(epoch, x):
-        return x * update_factor ** ((epoch + 1) % update_epochs == 0)
+    def scheduler(epoch: int, x: float) -> float:
+        return x * update_factor ** (epoch % update_epochs == 0 and epoch != 0)
+
+    return scheduler
+
+
+def create_warmup_scheduler(warmup_steps: int) -> Callable[[int, float], float]:
+    def scheduler(step: int, x: float) -> float:
+        if step == 0 and warmup_steps > 0:
+            return x / warmup_steps
+        if step >= warmup_steps:
+            return x
+        return x * (step + 1) / step
 
     return scheduler
 
@@ -19,6 +34,7 @@ def create_exponential_decay_scheduler(
 def default_supervised_model_callbacks(
     learning_rate_update_factor: float,
     learning_rate_update_epochs: int,
+    learning_rate_warmup_steps: int,
     use_weight_decay: bool = False,
     enable_early_stopping: bool = False,
     early_stopping_monitor: str = "val_loss",
@@ -28,16 +44,20 @@ def default_supervised_model_callbacks(
     early_stopping_use_best_epoch: bool = False,
     log_file: str = None,
     verbose: int = 2,
-) -> List[tf.keras.callbacks.Callback]:
-    scheduler = create_exponential_decay_scheduler(
-        learning_rate_update_factor, learning_rate_update_epochs
+) -> list[tf.keras.callbacks.Callback]:
+    decay_scheduler = create_exponential_decay_scheduler(
+        learning_rate_update_factor,
+        learning_rate_update_epochs,
     )
-    learning_rate_decay = tf.keras.callbacks.LearningRateScheduler(
-        scheduler, verbose=verbose
+    warmup_scheduler = create_warmup_scheduler(learning_rate_warmup_steps)
+    learning_rate_decay = LearningRateScheduler(
+        warmup_scheduler, decay_scheduler, verbose=verbose
     )
     callbacks = [learning_rate_decay]
     if use_weight_decay > 0:
-        callbacks.append(WeightDecayScheduler(scheduler, verbose=verbose))
+        callbacks.append(
+            WeightDecayScheduler(warmup_scheduler, decay_scheduler, verbose=verbose)
+        )
 
     if enable_early_stopping:
         callbacks.append(
@@ -55,8 +75,9 @@ def default_supervised_model_callbacks(
 
 
 __all__ = [
-    "ModelScoreCallback",
     "WeightDecayScheduler",
+    "LearningRateSchduler",
+    "TaggingFScoreMetric",
     "ModelSave",
     "default_supervised_model_callbacks",
-]
+]
\ No newline at end of file
