@@ -1,10 +1,10 @@
-from typing import Sequence, List, Union, Optional
+from __future__ import annotations
+from typing import Sequence, Union, Optional, Callable, Any
 
 import numpy as np
 import pandas as pd
 import tensorflow as tf
 
-from sknlp.vocab import Vocab
 from .nlp_dataset import NLPDataset
 from .utils import serialize_example
 
@@ -12,64 +12,74 @@ from .utils import serialize_example
 class ClassificationDataset(NLPDataset):
     def __init__(
         self,
-        vocab: Vocab,
+        tokenizer: Callable[[str], list[int]],
         labels: Sequence[str],
-        df: Optional[pd.DataFrame] = None,
+        X: Optional[Sequence[Any]] = None,
+        y: Optional[Sequence[Any]] = None,
         csv_file: Optional[str] = None,
         in_memory: bool = True,
+        no_label: bool = False,
         is_multilabel: bool = True,
         max_length: Optional[int] = None,
-        text_segmenter: str = "char",
         text_dtype: tf.DType = tf.int32,
         label_dtype: tf.DType = tf.float32,
-        text_padding_shape: tuple = (None,),
-        label_padding_shape: tuple = (None,),
-        text_padding_value: Union[str, int, float, None] = None,
-        label_padding_value: Union[str, int, float, None] = None,
     ):
-        self.vocab = vocab
         self.labels = list(labels)
         self.is_multilabel = is_multilabel
         self.label2idx = dict(zip(labels, range(len(labels))))
         super().__init__(
-            df=df,
+            tokenizer,
+            X=X,
+            y=y,
             csv_file=csv_file,
             in_memory=in_memory,
-            text_segmenter=text_segmenter,
+            no_label=no_label,
             max_length=max_length,
+            na_value="NULL",
+            column_dtypes=["str", "str"],
             text_dtype=text_dtype,
             label_dtype=label_dtype,
-            text_padding_shape=text_padding_shape,
-            label_padding_shape=label_padding_shape,
-            text_padding_value=text_padding_value or vocab[vocab.pad],
-            label_padding_value=label_padding_value or 0.0,
         )
 
-    def _text_transform(self, text: tf.Tensor) -> np.ndarray:
-        tokens = super()._text_transform(text)
-        return np.array(
-            [self.vocab[t] for t in tokens[: self.max_length]], dtype=np.int32
-        )
+    @property
+    def y(self) -> Union[list[str], list[list[str]]]:
+        if self.no_label:
+            return []
+        return [
+            data[-1].decode("UTF-8").split("|")
+            if self.is_multilabel
+            else data[-1].decode("UTF-8")
+            for data in self._original_dataset.as_numpy_iterator()
+        ]
 
-    def _label_binarizer(self, labels: List[str]) -> np.ndarray:
+    @property
+    def batch_padding_shapes(self) -> list[tuple]:
+        return ((None,), (None,))[: -1 if self.no_label else None]
+
+    def _normalize_y(self, y: Sequence[Any]) -> Sequence[Any]:
+        if isinstance(y[0], (list, tuple)):
+            return ["|".join(map(str, yi)) for yi in y]
+        return y
+
+    def _label_binarizer(self, labels: list[str]) -> np.ndarray:
         label2idx = self.label2idx
         res = np.zeros(len(label2idx), dtype=np.float32)
         res[[label2idx[label] for label in labels if label in label2idx]] = 1
         return res
 
     def _label_transform(self, label: tf.Tensor) -> np.ndarray:
-        label = super()._label_transform(label)
+        _label = super()._label_transform(label)
         if self.is_multilabel:
-            labels = label.split("|")
+            labels = _label.split("|")
         else:
-            labels = [label]
+            labels = [_label]
         return self._label_binarizer(labels)
 
     def to_tfrecord(self, filename: str) -> None:
         def func(text: np.ndarray, label: np.ndarray):
             return tf.reshape(
                 serialize_example(
-                    (self.text_transform(text), self.label_transform(label)),
+                    (self._text_transform(text), self._label_transform(label)),
                     ("tensor", "tensor"),
                 ),
                 (),
@@ -98,4 +108,4 @@ class ClassificationDataset(NLPDataset):
                 tf.io.parse_tensor(parsed_record["feature1"], tf.float32),
             )
 
-        return tf.data.TFRecordDataset(filename).map(func)
+        return tf.data.TFRecordDataset(filename).map(func)
\ No newline at end of file
