@@ -2,6 +2,7 @@ from __future__ import annotations
 import tensorflow as tf
 
 
+@tf.keras.utils.register_keras_serializable(package="sknlp")
 class MultiLabelCategoricalCrossentropy(tf.keras.losses.Loss):
     """
     苏剑林. (Apr. 25, 2020). 《将“softmax+交叉熵”推广到多标签分类问题 》[Blog post]. Retrieved from https://spaces.ac.cn/archives/7359
@@ -15,7 +16,10 @@ class MultiLabelCategoricalCrossentropy(tf.keras.losses.Loss):
         super().__init__(reduction=reduction, name=name)
 
     def call(self, y_true: tf.Tensor, y_pred: tf.Tensor) -> tf.Tensor:
-        y_pred = tf.convert_to_tensor(y_pred)
+        if isinstance(y_pred, tf.RaggedTensor):
+            y_pred = y_pred.to_tensor(0)
+        else:
+            y_pred = tf.convert_to_tensor(y_pred)
         y_true = tf.cast(y_true, y_pred.dtype)
         y_pred = (1 - 2 * y_true) * y_pred
         y_pred_neg: tf.Tensor = y_pred - y_true * 1e12
