@@ -4,7 +4,6 @@ from .precision_recall_f1 import (
     FBetaScoreWithLogits,
 )
 from .accuracy import BinaryAccuracyWithLogits, AccuracyWithLogits
-from .utils import logits2scores, logits2classes, scores2classes
 
 
 __all__ = [
@@ -13,7 +12,4 @@ __all__ = [
     "PrecisionWithLogits",
     "RecallWithLogits",
     "FBetaScoreWithLogits",
-    "logits2scores",
-    "logits2classes",
-    "scores2classes",
 ]
