@@ -5,7 +5,10 @@ import tensorflow as tf
 from tensorflow.keras.metrics import Precision, Recall
 from tensorflow_addons.metrics import FBetaScore
 
+from .utils import logits2pred
 
+
+@tf.keras.utils.register_keras_serializable(package="sknlp")
 class PrecisionWithLogits(Precision):
     def __init__(
         self,
@@ -31,7 +34,7 @@ class PrecisionWithLogits(Precision):
         y_logits: tf.Tensor,
         sample_weight: Optional[tf.Tensor] = None,
     ) -> None:
-        y_pred = tf.keras.activations.deserialize(self.activation)(y_logits)
+        y_pred = logits2pred(y_logits, self.activation)
         super().update_state(y_true, y_pred, sample_weight=sample_weight)
 
     def get_config(self) -> dict[str, Any]:
@@ -44,6 +47,7 @@ class PrecisionWithLogits(Precision):
         }
 
 
+@tf.keras.utils.register_keras_serializable(package="sknlp")
 class RecallWithLogits(Recall):
     def __init__(
         self,
@@ -69,7 +73,7 @@ class RecallWithLogits(Recall):
         y_logits: tf.Tensor,
         sample_weight: Optional[tf.Tensor] = None,
     ) -> None:
-        y_pred = tf.keras.activations.deserialize(self.activation)(y_logits)
+        y_pred = logits2pred(y_logits, self.activation)
         super().update_state(y_true, y_pred, sample_weight=sample_weight)
 
     def get_config(self) -> dict[str, Any]:
@@ -82,12 +86,14 @@ class RecallWithLogits(Recall):
         }
 
 
+@tf.keras.utils.register_keras_serializable(package="sknlp")
 class FBetaScoreWithLogits(FBetaScore):
     def __init__(
         self,
         num_classes: int,
         average: str = "micro",
         beta: float = 1.0,
+        class_id: Optional[int] = None,
         threshold: float = 0.5,
         name: str = "fbeta_score",
         dtype: Optional[tf.DType] = None,
@@ -101,6 +107,7 @@ class FBetaScoreWithLogits(FBetaScore):
             name=name,
             dtype=dtype,
         )
+        self.class_id = class_id
         self.activation = activation
 
     def update_state(
@@ -109,11 +116,15 @@ class FBetaScoreWithLogits(FBetaScore):
         y_logits: tf.Tensor,
         sample_weight: Optional[tf.Tensor] = None,
     ) -> None:
-        y_pred = tf.keras.activations.deserialize(self.activation)(y_logits)
+        y_pred = logits2pred(y_logits, self.activation)
+        if self.class_id is not None:
+            y_true = y_true[..., self.class_id]
+            y_pred = y_pred[..., self.class_id]
         super().update_state(y_true, y_pred, sample_weight=sample_weight)
 
     def get_config(self) -> dict[str, Any]:
         return {
             **super().get_config(),
             "activation": self.activation,
+            "class_id": self.class_id,
         }
\ No newline at end of file
