@@ -1,12 +1,12 @@
 from __future__ import annotations
-from typing import Sequence, List, Dict, Any, Optional, Union
+from typing import Sequence, Any, Optional, Union
 
 import numpy as np
 import pandas as pd
-from tabulate import tabulate
 import tensorflow as tf
 
 from sknlp.data import ClassificationDataset
+from sknlp.layers import MLPLayer
 from sknlp.losses import MultiLabelCategoricalCrossentropy
 from sknlp.metrics import PrecisionWithLogits, RecallWithLogits, FBetaScoreWithLogits
 from sknlp.utils.classification import (
@@ -20,18 +20,20 @@ from ..text2vec import Text2vec
 
 
 class DeepClassifier(SupervisedNLPModel):
+    dataset_class = ClassificationDataset
+    dataset_args = ["is_multilabel"]
+
     def __init__(
         self,
         classes: Sequence[str],
         is_multilabel: bool = True,
         max_sequence_length: Optional[int] = None,
-        sequence_length: Optional[int] = None,
-        segmenter: Optional[str] = "jieba",
-        embedding_size: int = 100,
-        use_batch_normalization: bool = True,
+        num_fc_layers: int = 2,
+        fc_hidden_size: int = 256,
+        fc_activation: str = "tanh",
         text2vec: Optional[Text2vec] = None,
         loss: Optional[str] = None,
-        loss_kwargs: Optional[Dict[str, Any]] = None,
+        loss_kwargs: Optional[dict[str, Any]] = None,
         **kwargs,
     ):
         classes = list(classes)
@@ -42,26 +44,21 @@ class DeepClassifier(SupervisedNLPModel):
         super().__init__(
             classes,
             max_sequence_length=max_sequence_length,
-            sequence_length=sequence_length,
-            segmenter=segmenter,
-            embedding_size=embedding_size,
             text2vec=text2vec,
             task="classification",
             **kwargs,
         )
         self._is_multilabel = is_multilabel
-        self._use_batch_normalization = use_batch_normalization
         self._loss = loss
         self._loss_kwargs = loss_kwargs
+        self.num_fc_layers = num_fc_layers
+        self.fc_hidden_size = fc_hidden_size
+        self.fc_activation = fc_activation
 
     @property
     def is_multilabel(self) -> bool:
         return self._is_multilabel
 
-    @property
-    def use_batch_normalization(self) -> bool:
-        return self._use_batch_normalization
-
     @property
     def thresholds(self) -> list[float]:
         _thresholds = [0.5 for _ in range(self.num_classes)]
@@ -81,47 +78,37 @@ class DeepClassifier(SupervisedNLPModel):
 
     def get_loss(self, *args, **kwargs) -> list[tf.keras.losses.Loss]:
         if self.is_multilabel:
+            if self._loss == "binary_crossentropy":
+                return tf.keras.losses.BinaryCrossentropy(from_logits=True)
             return MultiLabelCategoricalCrossentropy()
         else:
             return tf.keras.losses.CategoricalCrossentropy(from_logits=True)
 
-    def get_metrics(self, *args, **kwargs) -> List[tf.keras.metrics.Metric]:
+    def get_metrics(self, *args, **kwargs) -> list[tf.keras.metrics.Metric]:
         activation = "sigmoid" if self.is_multilabel else "softmax"
+        class_id = None
+        if self.num_classes == 2:
+            class_id = 1
         return [
-            PrecisionWithLogits(activation=activation),
-            RecallWithLogits(activation=activation),
-            FBetaScoreWithLogits(self.num_classes, activation=activation),
+            PrecisionWithLogits(activation=activation, class_id=class_id),
+            RecallWithLogits(activation=activation, class_id=class_id),
+            FBetaScoreWithLogits(
+                self.num_classes, activation=activation, class_id=class_id
+            ),
         ]
 
     @classmethod
     def get_monitor(cls) -> str:
         return "val_fbeta_score"
 
-    def create_dataset_from_df(
-        self, df: pd.DataFrame, no_label: bool = False
-    ) -> ClassificationDataset:
-        return ClassificationDataset(
-            self.text2vec.vocab,
-            self.classes,
-            df=df,
-            is_multilabel=self.is_multilabel,
-            max_length=self.max_sequence_length,
-            no_label=no_label,
-            text_segmenter=self.text2vec.segmenter,
-        )
-
-    def create_dataset_from_csv(
-        self, filename: str, no_label: bool = False
-    ) -> ClassificationDataset:
-        return ClassificationDataset(
-            self.text2vec.vocab,
-            self.classes,
-            csv_file=filename,
-            is_multilabel=self.is_multilabel,
-            max_length=self.max_sequence_length,
-            no_label=no_label,
-            text_segmenter=self.text2vec.segmenter,
-        )
+    def build_output_layer(self, inputs: tf.Tensor) -> tf.Tensor:
+        return MLPLayer(
+            self.num_fc_layers,
+            hidden_size=self.fc_hidden_size,
+            output_size=self.num_classes,
+            activation=self.fc_activation,
+            name="mlp",
+        )(inputs)
 
     def predict_proba(
         self,
@@ -138,22 +125,19 @@ class DeepClassifier(SupervisedNLPModel):
         X: Sequence[str] = None,
         *,
         dataset: ClassificationDataset = None,
-        thresholds: Union[float, List[float], None] = None,
+        thresholds: Union[float, list[float], None] = None,
         batch_size: int = 128,
-    ) -> Union[List[str], List[List[str]]]:
+    ) -> Union[list[str], list[list[str]]]:
         probabilities = self.predict_proba(X=X, dataset=dataset, batch_size=batch_size)
         predictions = probabilities2classes(
             probabilities, self.is_multilabel, thresholds=thresholds or self.thresholds
         )
         if self.is_multilabel:
             return [
-                [self.idx2class(i) for i in prediction if self.idx2class(i) != "NULL"]
-                for prediction in predictions
+                [self.idx2class(i) for i in prediction] for prediction in predictions
             ]
         else:
-            return [
-                self.idx2class(i) for i in predictions if self.idx2class(i) != "NULL"
-            ]
+            return [self.idx2class(i) for i in predictions if self.idx2class(i)]
 
     def score(
         self,
@@ -161,39 +145,27 @@ class DeepClassifier(SupervisedNLPModel):
         y: Union[Sequence[Sequence[str]], Sequence[str]] = None,
         *,
         dataset: ClassificationDataset = None,
-        thresholds: Union[float, List[float], None] = None,
+        thresholds: Union[float, list[float], None] = None,
         batch_size: int = 128,
     ) -> pd.DataFrame:
         dataset = self.prepare_dataset(X, y, dataset)
         predictions = self.predict(
             dataset=dataset, thresholds=thresholds, batch_size=batch_size
         )
-        return classification_fscore(dataset.y, predictions, classes=self.classes[1:])
+        return classification_fscore(
+            dataset.y,
+            predictions,
+            self.classes[1:] if self.num_classes > 2 else self.classes,
+        )
 
-    @classmethod
-    def format_score(cls, score_df: pd.DataFrame, format: str = "markdown") -> str:
-        return tabulate(score_df, headers="keys", tablefmt="github", showindex=False)
-
-    def get_config(self) -> Dict[str, Any]:
+    def get_config(self) -> dict[str, Any]:
         return {
             **super().get_config(),
             "is_multilabel": self.is_multilabel,
-            "use_batch_normalization": self.use_batch_normalization,
         }
 
     @classmethod
-    def _filter_config(cls, config):
-        config = super()._filter_config(config)
-        config.pop("algorithm", None)
+    def from_config(cls, config: dict[str, Any]) -> "DeepClassifier":
         config.pop("task", None)
-        return config
-
-    @classmethod
-    def get_custom_objects(cls) -> Dict[str, Any]:
-        return {
-            **super().get_custom_objects(),
-            "MultiLabelCategoricalCrossentropy": MultiLabelCategoricalCrossentropy,
-            "PrecisionWithLogits": PrecisionWithLogits,
-            "RecallWithLogits": RecallWithLogits,
-            "FBetaScoreWithLogits": FBetaScoreWithLogits,
-        }
\ No newline at end of file
+        config.pop("algorithm", None)
+        return super().from_config(config)
\ No newline at end of file
